@@ -2,9 +2,10 @@ from __future__ import annotations
 
 from typing import Any, SupportsInt, TypeAlias, TypeVar, cast, overload
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, ValidationError
 from xmltodict import parse as xml_parse
 
+from ..exceptions import OmniParsingException
 from ..types import (
     BackyardState,
     ChlorinatorOperatingMode,
@@ -46,8 +47,9 @@ class TelemetryBackyard(BaseModel):
     status_version: int = Field(alias="@statusVersion")
     air_temp: int = Field(alias="@airTemp")
     state: BackyardState | int = Field(alias="@state")
-    config_checksum: int = Field(alias="@ConfigChksum")
-    msp_version: str = Field(alias="@mspVersion")
+    # The below two fields are only available for telemetry with a status_version >= 11
+    config_checksum: int | None = Field(alias="@ConfigChksum")
+    msp_version: str | None = Field(alias="@mspVersion")
 
 
 class TelemetryBoW(BaseModel):
@@ -114,7 +116,7 @@ class TelemetryPump(BaseModel):
     omni_type: OmniType = OmniType.PUMP
     system_id: int = Field(alias="@systemId")
     state: PumpState | int = Field(alias="@pumpState")
-    speed: int = Field(alias="@pummpSpeed")
+    speed: int = Field(alias="@pumpSpeed")
     last_speed: int = Field(alias="@lastSpeed")
     why_on: int = Field(alias="@whyOn")
 
@@ -171,7 +173,7 @@ class Telemetry(BaseModel):
     pump: list[TelemetryPump] | None = Field(alias="Pump")
     relay: list[TelemetryRelay] | None = Field(alias="Relay")
     valve_actuator: list[TelemetryValveActuator] | None = Field(alias="ValveActuator")
-    virtual_heater: TelemetryVirtualHeater | None = Field(alias="VirtualHeater")
+    virtual_heater: list[TelemetryVirtualHeater] | None = Field(alias="VirtualHeater")
 
     class Config:
         orm_mode = True
@@ -224,9 +226,13 @@ class Telemetry(BaseModel):
                 OmniType.PUMP,
                 OmniType.RELAY,
                 OmniType.VALVE_ACTUATOR,
+                OmniType.VIRT_HEATER,
             ),
         )
-        return Telemetry.parse_obj(data["STATUS"])
+        try:
+            return Telemetry.parse_obj(data["STATUS"])
+        except ValidationError as exc:
+            raise OmniParsingException(f"Failed to parse Telemetry: {exc}") from exc
 
     def get_telem_by_systemid(self, system_id: int) -> TelemetryType | None:
         for field_name, value in self:
